summaryrefslogtreecommitdiff
path: root/var/spack/repos/builtin/packages/git/package.py
diff options
context:
space:
mode:
Diffstat (limited to 'var/spack/repos/builtin/packages/git/package.py')
-rw-r--r--var/spack/repos/builtin/packages/git/package.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/var/spack/repos/builtin/packages/git/package.py b/var/spack/repos/builtin/packages/git/package.py
index 8828d68238..ceb4e2ccb0 100644
--- a/var/spack/repos/builtin/packages/git/package.py
+++ b/var/spack/repos/builtin/packages/git/package.py
@@ -185,13 +185,13 @@ class Git(AutotoolsPackage):
depends_on('m4', type='build')
depends_on('tk', type=('build', 'link'), when='+tcltk')
# See the comment in setup_environment re EXTLIBS.
def patch(self):
filter_file(r'^EXTLIBS =$',
'#EXTLIBS =',
'Makefile')
- def setup_environment(self, spack_env, run_env):
+ def setup_build_environment(self, env):
# We use EXTLIBS rather than LDFLAGS so that git's Makefile
# inserts the information into the proper place in the link commands
# (alongside the # other libraries/paths that configure discovers).
@@ -204,9 +204,9 @@ class Git(AutotoolsPackage):
# In that case the node in the DAG gets truncated and git DOES NOT
# have a gettext dependency.
if 'gettext' in self.spec:
- spack_env.append_flags('EXTLIBS', '-L{0} -lintl'.format(
+ env.append_flags('EXTLIBS', '-L{0} -lintl'.format(
self.spec['gettext'].prefix.lib))
- spack_env.append_flags('CFLAGS', '-I{0}'.format(
+ env.append_flags('CFLAGS', '-I{0}'.format(
self.spec['gettext'].prefix.include))
def configure_args(self):
@@ -185,13 +185,13 @@ class Git(AutotoolsPackage):
depends_on('m4', type='build')
depends_on('tk', type=('build', 'link'), when='+tcltk')
- # See the comment in setup_environment re EXTLIBS.
+ # See the comment in setup_build_environment re EXTLIBS.
def patch(self):
filter_file(r'^EXTLIBS =$',